@@ -1,22 +1,23 @@
 #![allow(non_camel_case_types)]
 #![allow(non_upper_case_globals)]
-#![cfg_attr(not(feature = "use_std"), no_std)]
-#![cfg_attr(feature = "unstable", feature(repr_packed))]
-#![cfg_attr(
-    feature = "cargo-clippy",
-    allow(
-        clippy::stutter,
-        clippy::cast_sign_loss,
-        clippy::cast_possible_truncation,
-        clippy::trivially_copy_pass_by_ref
-    )
+#![deny(missing_debug_implementations)]
+#![deny(missing_copy_implementations)]
+#![allow(
+    clippy::module_name_repetitions,
+    clippy::cast_sign_loss,
+    clippy::cast_possible_truncation,
+    clippy::trivially_copy_pass_by_ref
 )]
+#![no_std]
 
-#[cfg(feature = "use_std")]
-extern crate core;
+#[cfg(not(any(target_os = "macos", target_os = "ios")))]
+compile_error!("mach requires macOS or iOS");
 
 extern crate libc;
 
+#[allow(unused_imports)]
+use core::{clone, cmp, default, fmt, hash, marker, mem, option};
+
 pub mod boolean;
 pub mod bootstrap;
 pub mod clock;
@@ -30,6 +31,7 @@ pub mod exception_types;
 pub mod kern_return;
 pub mod mach_init;
 pub mod mach_port;
+pub mod mach_time;
 pub mod mach_types;
 pub mod memory_object_types;
 pub mod message;
